pub struct KvIterDebug<T>(/* private fields */);Expand description
IterDebug but styled with key-value formatting
Note that an iterator can only be debugged once, aim to wrap your iterator as late as possible, usually directly in the print / format statement.
Implementations
Sourceimpl<T> KvIterDebug<T>
impl<T> KvIterDebug<T>